@@ -1,13 +1,9 @@
-extern crate libc;
-extern crate seccomp_sys;
-#[macro_use]
-extern crate log;
-extern crate strum;
-#[macro_use]
-extern crate strum_macros;
-
+use log::*;
 use seccomp_sys::*;
 
+// workaround until we can assume libseccomp >= 2.4.0 is always present
+include!(concat!(env!("OUT_DIR"), "/const.rs"));
+
 mod rule;
 pub use rule::{Cmp, Comparator};
 
@@ -19,7 +15,8 @@ pub use syscalls::Syscall;
 
 #[derive(Debug, Clone, Copy)]
 pub enum Action {
-    Kill,
+    KillProcess,
+    KillThread,
     Trap,
     Errno(u16),
     Trace(u16),
@@ -30,7 +27,8 @@ impl Into<u32> for Action {
     fn into(self) -> u32 {
         use self::Action::*;
         match self {
-            Kill => SCMP_ACT_KILL,
+            KillProcess => SCMP_ACT_KILL_PROCESS,
+            KillThread => SCMP_ACT_KILL,
             Trap => SCMP_ACT_TRAP,
             Errno(e) => SCMP_ACT_ERRNO(e.into()),
             Trace(t) => SCMP_ACT_TRACE(t.into()),
@@ -45,7 +43,7 @@ pub struct Context {
 
 impl Context {
     pub fn init() -> Result<Context> {
-        Context::init_with_action(Action::Kill)
+        Context::init_with_action(DEFAULT_KILL)
     }
 
     pub fn init_with_action(default_action: Action) -> Result<Context> {
@@ -147,7 +145,7 @@ mod tests {
         use crate::syscalls::Syscall;
 
         let cases = vec![
-            ("open", Some(Syscall::open)),
+            ("write", Some(Syscall::write)),
             ("setgid", Some(Syscall::setgid)),
             ("nothing", None),
             ("", None),
